@@ -1,5 +1,5 @@
 package Pithub::Base;
-$Pithub::Base::VERSION = '0.01029';
+$Pithub::Base::VERSION = '0.01030';
 our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 base class for all Pithub modules
@@ -179,6 +179,7 @@ my @TOKEN_REQUIRED_REGEXP = (
     qr{^PUT /repos/[^/]+/[^/]+/issues/[^/]+/labels$},
     qr{^PUT /repos/[^/]+/[^/]+/pulls/[^/]+/merge$},
     qr{^PUT /teams/[^/]+/members/.*$},
+    qr{^PUT /teams/[^/]+/memberships/.*$},
     qr{^PUT /teams/[^/]+/repos/.*$},
     qr{^PUT /user/following/.*$},
     qr{^PUT /user/starred/[^/]+/.*$},
@@ -283,7 +284,7 @@ sub has_token {
 
 sub _build__json {
     my ($self) = @_;
-    return JSON->new;
+    return JSON->new->utf8;
 }
 
 sub _build_ua {
@@ -404,7 +405,7 @@ Pithub::Base - Github v3 base class for all Pithub modules
 
 =head1 VERSION
 
-version 0.01029
+version 0.01030
 
 =head1 DESCRIPTION
 
