@@ -1,16 +1,17 @@
 package Pithub::Orgs::Teams;
-$Pithub::Orgs::Teams::VERSION = '0.01029';
+$Pithub::Orgs::Teams::VERSION = '0.01030';
 our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 Org Teams API
 
 use Moo;
-use Carp qw(croak);
+use Carp qw(croak carp);
 extends 'Pithub::Base';
 
 
 sub add_member {
     my ( $self, %args ) = @_;
+    carp '"Add team member" API is deprecated. Use add_membership method.';
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
     return $self->request(
@@ -21,6 +22,19 @@ sub add_member {
 }
 
 
+sub add_membership {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: team_id' unless $args{team_id};
+    croak 'Missing key in parameters: user'    unless $args{user};
+    croak 'Missing key in parameters: data'    unless $args{data};
+    return $self->request(
+        method => 'PUT',
+        path   => sprintf( '/teams/%s/memberships/%s', delete $args{team_id}, delete $args{user} ),
+        %args,
+    );
+}
+
+
 sub add_repo {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
@@ -130,6 +144,7 @@ sub list_repos {
 
 sub remove_member {
     my ( $self, %args ) = @_;
+    carp '"Remove team member" API is deprecated. Use remove_membership method.';
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
     return $self->request(
@@ -140,6 +155,18 @@ sub remove_member {
 }
 
 
+sub remove_membership {
+    my ( $self, %args ) = @_;
+    croak 'Missing key in parameters: team_id' unless $args{team_id};
+    croak 'Missing key in parameters: user'    unless $args{user};
+    return $self->request(
+        method => 'DELETE',
+        path   => sprintf( '/teams/%s/memberships/%s', delete $args{team_id}, delete $args{user} ),
+        %args,
+    );
+}
+
+
 sub remove_repo {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
@@ -177,7 +204,7 @@ Pithub::Orgs::Teams - Github v3 Org Teams API
 
 =head1 VERSION
 
-version 0.01029
+version 0.01030
 
 =head1 METHODS
 
@@ -185,6 +212,11 @@ version 0.01029
 
 =over
 
+The "Add team member" API (described below) is deprecated and is
+scheduled for removal in the next major version of the API. We
+recommend using the Add team membership API instead. It allows
+you to invite new organization members to your teams.
+
 In order to add a user to a team, the authenticated user must have
 'admin' permissions to the team or be an owner of the org that the
 team is associated with.
@@ -201,6 +233,30 @@ Examples:
 
 =back
 
+=head2 add_membership
+
+=over
+
+If the user is already a member of the team’s organization, this
+endpoint will add the user to the team. In order to add a membership
+between an organization member and a team, the authenticated user
+must be an organization owner or a maintainer of the team.
+
+    PUT /teams/:id/memberships/:user
+
+Examples:
+
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->add_membership(
+        team_id => 1,
+        user    => 'plu',
+        data    => {
+            role => 'member',
+        }
+    );
+
+=back
+
 =head2 add_repo
 
 =over
@@ -362,6 +418,11 @@ Examples:
 
 =over
 
+The "Remove team member" API (described below) is deprecated and
+is scheduled for removal in the next major version of the API. We
+recommend using the Remove team membership API instead. It allows
+you to remove both active and pending memberships.
+
 In order to remove a user from a team, the authenticated user must
 have 'admin' permissions to the team or be an owner of the org that
 the team is associated with. NOTE: This does not delete the user,
@@ -379,6 +440,28 @@ Examples:
 
 =back
 
+=head2 remove_membership
+
+=over
+
+In order to remove a membership between a user and a team,
+the authenticated user must have 'admin' permissions to
+the team or be an owner of the organization that the team
+is associated with. NOTE: This does not delete the user,
+it just removes their membership from the team.
+
+    DELETE /teams/:id/memberships/:user
+
+Examples:
+
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->remove_membership(
+        team_id => 1,
+        user    => 'plu',
+    );
+
+=back
+
 =head2 remove_repo
 
 =over
