@@ -1,5 +1,5 @@
 package Pithub::Repos::Statuses;
-$Pithub::Repos::Statuses::VERSION = '0.01029';
+$Pithub::Repos::Statuses::VERSION = '0.01030';
 our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT:  Github v3 repos / statuses API
@@ -64,7 +64,7 @@ Pithub::Repos::Statuses - Github v3 repos / statuses API
 
 =head1 VERSION
 
-version 0.01029
+version 0.01030
 
 =head1 METHODS
 
@@ -120,7 +120,7 @@ Examples:
     my $result   = $statuses->create( user => 'plu', repo => 'Pithub',
         sha => '0123456', 
         data => {
-            status => 'error',
+            state => 'error',
             description => 'Build failed',
             target_url => 'https://travis-ci.org/some/url/0123456',
         },
