@@ -1,5 +1,5 @@
 package Pithub::Result;
-$Pithub::Result::VERSION = '0.01029';
+$Pithub::Result::VERSION = '0.01030';
 our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 result object
@@ -253,7 +253,7 @@ sub _build_prev_page_uri {
 
 sub _build__json {
     my ($self) = @_;
-    return JSON->new;
+    return JSON->new->utf8;
 }
 
 sub _get_link_header {
@@ -312,7 +312,7 @@ Pithub::Result - Github v3 result object
 
 =head1 VERSION
 
-version 0.01029
+version 0.01030
 
 =head1 DESCRIPTION
 
